@@ -7,12 +7,10 @@ Module that contains Standalone plugin specific implementation
 
 from __future__ import print_function, division, absolute_import
 
-from artella import register
 from artella.core import dccplugin
-from artella.core.utils import Singleton
 
 
-class ArtellaStandalonePlugin(dccplugin.ArtellaDccPlugin, object):
+class ArtellaStandalonePlugin(dccplugin.BaseArtellaDccPlugin):
 
     def init(self, dev=False, show_dialogs=True, create_menu=True, create_callbacks=True, *args, **kwargs):
         """
@@ -27,12 +25,3 @@ class ArtellaStandalonePlugin(dccplugin.ArtellaDccPlugin, object):
         """
 
         super(ArtellaStandalonePlugin, self).init(dev=dev, show_dialogs=show_dialogs)
-
-
-@Singleton
-class ArtellaStandalonePluginSingleton(ArtellaStandalonePlugin, object):
-    def __init__(self, artella_drive_client=None):
-        ArtellaStandalonePlugin.__init__(self, artella_drive_client=artella_drive_client)
-
-
-register.register_class('DccPlugin', ArtellaStandalonePluginSingleton)
